@@ -23,9 +23,9 @@ use warnings;
 
 use POSIX qw(tzset);
 
-our($VERSION, $canonical_time, $clamp_time);
+our($VERSION, $canonical_time, $clamp_time, $verbose);
 
-$VERSION = '0.041'; # 0.041
+$VERSION = '1.6.3'; # <https://semver.org/>
 
 sub init() {
 	$ENV{'TZ'} = 'UTC';
@@ -35,7 +35,7 @@ sub init() {
 sub _get_file_type($) {
 	my $file=shift;
 	open(FILE, '-|') # handle all filenames safely
-	  || exec('file', $file)
+	  || exec('file', _internal_optional_file_args(), '--', $file)
 	  || die "can't exec file: $!";
 	my $type=<FILE>;
 	close FILE;
@@ -68,6 +68,16 @@ sub get_normalizer_for_file($) {
 		&& _get_file_type($_) =~ m/(Java|Zip) archive data/) {
 		return _handler('jar');
 	}
+	# jmod
+	if (m/\.jmod$/) {
+		# Loading the handler forces the load of the jmod package as well
+		my $handler = _handler('jmod');
+
+		# Only recent versions of file(1) can detect Jmod file so we
+		# perform a manual test.
+		return $handler
+		  if File::StripNondeterminism::handlers::jmod::is_jmod_file($_);
+	}
 	# javadoc
 	if (m/\.html$/) {
 		# Loading the handler forces the load of the javadoc package as well
@@ -93,17 +103,8 @@ sub get_normalizer_for_file($) {
 	if (m/\.png$/ && _get_file_type($_) =~ m/PNG image data/) {
 		return _handler('png');
 	}
-	# pom.properties, version.properties
-	if (m/\.properties$/) {
-	# Loading the handler forces the load of the javaproperties package as well
-		my $handler = _handler('javaproperties');
-		return $handler
-		  if
-		  File::StripNondeterminism::handlers::javaproperties::is_java_properties_file(
-			$_);
-	}
 	# zip
-	if (m/\.(zip|pk3|epub|whl|xpi|htb|zhfst|par)$/
+	if (m/\.(zip|pk3|epub|whl|xpi|htb|zhfst|par|codadef)$/
 		&& _get_file_type($_) =~ m/Zip archive data|EPUB document/) {
 		return _handler('zip');
 	}
@@ -112,25 +113,55 @@ sub get_normalizer_for_file($) {
 
 our %HANDLER_CACHE;
 our %KNOWN_HANDLERS = (
-	ar	=> 1,
+	ar	=> 0,
 	bflt	=> 1,
 	cpio	=> 1,
 	gettext	=> 1,
 	gzip	=> 1,
 	jar	=> 1,
 	javadoc	=> 1,
+	jmod	=> 1,
 	uimage	=> 1,
 	png	=> 1,
 	javaproperties => 1,
 	zip	=> 1,
 );
 
+sub all_normalizers () {
+	return sort keys %KNOWN_HANDLERS;
+}
+
+sub enabled_normalizers () {
+	my @normalizers;
+	foreach my $x (all_normalizers()) {
+		push @normalizers, $x if $KNOWN_HANDLERS{$x};
+	}
+	return @normalizers;
+}
+
+sub enable_normalizer ($) {
+	my ($name) = @_;
+	die("Unknown normalizer: ${name}")
+	  if not exists($KNOWN_HANDLERS{$name});
+	$KNOWN_HANDLERS{$name} = 1;
+}
+
+sub disable_normalizer ($) {
+	my ($name) = @_;
+	die("Unknown normalizer: ${name}")
+	  if not exists($KNOWN_HANDLERS{$name});
+	$KNOWN_HANDLERS{$name} = 0;
+}
+
 sub _handler {
+	# Returns the normalize routine for this handler or 0 (not undef)
+	# if the handler is not enabled.
 	my ($handler_name) = @_;
 	return $HANDLER_CACHE{$handler_name}
 	  if exists($HANDLER_CACHE{$handler_name});
 	die("Unknown handler: ${handler_name}\n")
 	  if not exists($KNOWN_HANDLERS{$handler_name});
+	return 0 if !$KNOWN_HANDLERS{$handler_name};
 	my $pkg = "File::StripNondeterminism::handlers::${handler_name}";
 	my $mod = "File/StripNondeterminism/handlers/${handler_name}.pm";
 	my $sub_name = "${pkg}::normalize";
@@ -148,4 +179,23 @@ sub get_normalizer_by_name($) {
 	return _handler(shift);
 }
 
+# From Debian::Debhelper::Dh_Lib
+my $_disable_file_seccomp;
+
+sub _internal_optional_file_args {
+	if (not defined($_disable_file_seccomp)) {
+		my $consider_disabling_seccomp = 0;
+		if ($ENV{'FAKEROOTKEY'} or ($ENV{'LD_PRELOAD'}//'') =~ m/fakeroot/) {
+			$consider_disabling_seccomp = 1;
+		}
+		if ($consider_disabling_seccomp) {
+			my $has_no_sandbox = (qx/file --help/ // '') =~ m/--no-sandbox/;
+			$consider_disabling_seccomp = 0 if not $has_no_sandbox;
+		}
+		$_disable_file_seccomp = $consider_disabling_seccomp;
+	}
+	return ('--no-sandbox') if $_disable_file_seccomp;
+	return;
+}
+
 1;
